@@ -229,6 +229,11 @@ impl MatchRequest {
         }
     }
 
+    pub fn exclude(&mut self, exclude: Option<Vec<String>>) -> &mut MatchRequest {
+        self.general_options.exclude(&exclude);
+        self
+    }
+
     pub fn skip_waypoints(&mut self, val: bool) -> &mut MatchRequest {
         self.general_options.skip_waypoints(val);
         self
